<template>
  <ElectricBillRechargeBaseForm ref="formRef" v-model:form="form">
    <NutFormItem label="备注信息" class="bole-form-item" prop="remark">
      <NutInput
        v-model.trim="form.remark"
        class="bole-input-text"
        placeholder="请输入备注信息"
        type="text"
        max-length="30"
      />
    </NutFormItem>
    <div class="common-content">
      <nut-button class="recharge-button" type="primary" @click="handleNext">
        <div class="recharge-button-inner">
          <div class="recharge-button-text">立即充值</div>
        </div>
      </nut-button>
      <nut-button class="recharge-button" type="primary" plain @click="goToNext">
        <div class="recharge-button-inner">
          <div class="recharge-button-text">返回</div>
        </div>
      </nut-button>
    </div>
  </ElectricBillRechargeBaseForm>
</template>

<script setup lang="ts">
import { Button as NutButton, FormItem as NutFormItem, Input as NutInput } from '@nutui/nutui-taro';
import { reactive, ref } from 'vue';
import { useElectricBillRechargeContext } from './context';
import ElectricBillRechargeBaseForm from './ElectricBillRechargeBaseForm.vue';
import {
  useLifeRechargeContext,
  LifeRechargeConstants,
  AddUpdateUserAccountInput,
} from '@life-payment/core-vue';
import { useAddUpdateUserAccount } from '../../hooks';

defineOptions({
  name: 'ElectricBillRechargeStep1',
});

const form = reactive({
  electricAccount: '',
  electricType: '',
  electricAccountType: '',
  province: '',
  city: '',
  sixID: '',
  remark: '',
});

const { goToNext } = useElectricBillRechargeContext();

const formRef = ref<any>(null);

function handleNext() {
  if (!formRef.value) return;
  formRef.value.validate().then(({ valid, errors }: any) => {
    if (valid) {
      handleAddUpdateUserAccount();
    }
  });
}

const { addUpdateUserAccount } = useAddUpdateUserAccount();
const { blLifeRecharge } = useLifeRechargeContext();

async function handleAddUpdateUserAccount() {
  try {
    let params: AddUpdateUserAccountInput = {
      userId: blLifeRecharge.accountModel.userId,
      lifePayType: LifeRechargeConstants.LifePayOrderTypeEnum.电费订单,
      content: form.electricAccount,
      province: form.province,
      city: form.city,
      extraProperties: JSON.stringify(form),
      remark: form.remark,
    };
    await addUpdateUserAccount(params);
    goToNext();
  } catch (error) {}
}
</script>
